# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litecms/task/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litecms\\Task\\": "packages/litecms/task/src",
            "Litecms\\Task\\Seeders\\": "packages/litecms/task/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litecms\Task\Providers\TaskServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Task'  => Litecms\Task\Facades\Task::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litecms\\Task\\Seeders\\TaskTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litecms\Task\Providers\TaskServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litecms\Task\Providers\TaskServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litecms\Task\Providers\TaskServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/task/{modulename}

**User**

    http://path-to-route-folder/user/task/{modulename}

**Public**

    http://path-to-route-folder/tasks


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/task/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/task/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/task/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/task/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/task/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/task/{modulename}/{slug}
    METHOD: GET