<?php

namespace Litecms\Task\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Litecms\Task\Interfaces\TaskRepositoryInterface;
use Litecms\Task\Repositories\Eloquent\Filters\TaskPublicFilter;
use Litecms\Task\Repositories\Eloquent\Presenters\TaskListPresenter;

class TaskPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        TaskRepositoryInterface $task
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('litecms.task.modules'), 'task', guard_url('task'));
        $this->repository = $task;
    }

    /**
     * Show task's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(TaskPublicFilter::class)
            ->setPresenter(TaskListPresenter::class)
            ->select('tasks.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('task::task.names'))
            ->view('task::public.task.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show task.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('task::task.name'))
            ->view('task::public.task.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
